from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="UpdateUserPassword")


@_attrs_define
class UpdateUserPassword:
    """The update user password request body.

    Attributes:
        current_password (Union[Unset, None, str]): Gets or sets the current sha1-hashed password.
        current_pw (Union[Unset, None, str]): Gets or sets the current plain text password.
        new_pw (Union[Unset, None, str]): Gets or sets the new plain text password.
        reset_password (Union[Unset, bool]): Gets or sets a value indicating whether to reset the password.
    """

    current_password: Union[Unset, None, str] = UNSET
    current_pw: Union[Unset, None, str] = UNSET
    new_pw: Union[Unset, None, str] = UNSET
    reset_password: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        current_password = self.current_password
        current_pw = self.current_pw
        new_pw = self.new_pw
        reset_password = self.reset_password

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if current_password is not UNSET:
            field_dict["CurrentPassword"] = current_password
        if current_pw is not UNSET:
            field_dict["CurrentPw"] = current_pw
        if new_pw is not UNSET:
            field_dict["NewPw"] = new_pw
        if reset_password is not UNSET:
            field_dict["ResetPassword"] = reset_password

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        current_password = d.pop("CurrentPassword", UNSET)

        current_pw = d.pop("CurrentPw", UNSET)

        new_pw = d.pop("NewPw", UNSET)

        reset_password = d.pop("ResetPassword", UNSET)

        update_user_password = cls(
            current_password=current_password,
            current_pw=current_pw,
            new_pw=new_pw,
            reset_password=reset_password,
        )

        return update_user_password



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.name_id_pair import NameIdPair
    from ..models.name_value_pair import NameValuePair
    from ..models.tuner_channel_mapping import TunerChannelMapping


T = TypeVar("T", bound="ChannelMappingOptionsDto")


@_attrs_define
class ChannelMappingOptionsDto:
    """Channel mapping options dto.

    Attributes:
        tuner_channels (Union[Unset, List['TunerChannelMapping']]): Gets or sets list of tuner channels.
        provider_channels (Union[Unset, List['NameIdPair']]): Gets or sets list of provider channels.
        mappings (Union[Unset, List['NameValuePair']]): Gets or sets list of mappings.
        provider_name (Union[Unset, None, str]): Gets or sets provider name.
    """

    tuner_channels: Union[Unset, List["TunerChannelMapping"]] = UNSET
    provider_channels: Union[Unset, List["NameIdPair"]] = UNSET
    mappings: Union[Unset, List["NameValuePair"]] = UNSET
    provider_name: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        tuner_channels: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.tuner_channels, Unset):
            tuner_channels = []
            for tuner_channels_item_data in self.tuner_channels:
                tuner_channels_item = tuner_channels_item_data.to_dict()

                tuner_channels.append(tuner_channels_item)

        provider_channels: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.provider_channels, Unset):
            provider_channels = []
            for provider_channels_item_data in self.provider_channels:
                provider_channels_item = provider_channels_item_data.to_dict()

                provider_channels.append(provider_channels_item)

        mappings: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.mappings, Unset):
            mappings = []
            for mappings_item_data in self.mappings:
                mappings_item = mappings_item_data.to_dict()

                mappings.append(mappings_item)

        provider_name = self.provider_name

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if tuner_channels is not UNSET:
            field_dict["TunerChannels"] = tuner_channels
        if provider_channels is not UNSET:
            field_dict["ProviderChannels"] = provider_channels
        if mappings is not UNSET:
            field_dict["Mappings"] = mappings
        if provider_name is not UNSET:
            field_dict["ProviderName"] = provider_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.name_id_pair import NameIdPair
        from ..models.name_value_pair import NameValuePair
        from ..models.tuner_channel_mapping import TunerChannelMapping

        d = src_dict.copy()
        tuner_channels = []
        _tuner_channels = d.pop("TunerChannels", UNSET)
        for tuner_channels_item_data in _tuner_channels or []:
            tuner_channels_item = TunerChannelMapping.from_dict(tuner_channels_item_data)

            tuner_channels.append(tuner_channels_item)

        provider_channels = []
        _provider_channels = d.pop("ProviderChannels", UNSET)
        for provider_channels_item_data in _provider_channels or []:
            provider_channels_item = NameIdPair.from_dict(provider_channels_item_data)

            provider_channels.append(provider_channels_item)

        mappings = []
        _mappings = d.pop("Mappings", UNSET)
        for mappings_item_data in _mappings or []:
            mappings_item = NameValuePair.from_dict(mappings_item_data)

            mappings.append(mappings_item)

        provider_name = d.pop("ProviderName", UNSET)

        channel_mapping_options_dto = cls(
            tuner_channels=tuner_channels,
            provider_channels=provider_channels,
            mappings=mappings,
            provider_name=provider_name,
        )

        return channel_mapping_options_dto



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..models.task_completion_status import TaskCompletionStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="TaskResult")


@_attrs_define
class TaskResult:
    """Class TaskExecutionInfo.

    Attributes:
        start_time_utc (Union[Unset, datetime.datetime]): Gets or sets the start time UTC.
        end_time_utc (Union[Unset, datetime.datetime]): Gets or sets the end time UTC.
        status (Union[Unset, TaskCompletionStatus]): Enum TaskCompletionStatus.
        name (Union[Unset, None, str]): Gets or sets the name.
        key (Union[Unset, None, str]): Gets or sets the key.
        id (Union[Unset, None, str]): Gets or sets the id.
        error_message (Union[Unset, None, str]): Gets or sets the error message.
        long_error_message (Union[Unset, None, str]): Gets or sets the long error message.
    """

    start_time_utc: Union[Unset, datetime.datetime] = UNSET
    end_time_utc: Union[Unset, datetime.datetime] = UNSET
    status: Union[Unset, TaskCompletionStatus] = UNSET
    name: Union[Unset, None, str] = UNSET
    key: Union[Unset, None, str] = UNSET
    id: Union[Unset, None, str] = UNSET
    error_message: Union[Unset, None, str] = UNSET
    long_error_message: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        start_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.start_time_utc, Unset):
            start_time_utc = self.start_time_utc.isoformat()

        end_time_utc: Union[Unset, str] = UNSET
        if not isinstance(self.end_time_utc, Unset):
            end_time_utc = self.end_time_utc.isoformat()

        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        name = self.name
        key = self.key
        id = self.id
        error_message = self.error_message
        long_error_message = self.long_error_message

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if start_time_utc is not UNSET:
            field_dict["StartTimeUtc"] = start_time_utc
        if end_time_utc is not UNSET:
            field_dict["EndTimeUtc"] = end_time_utc
        if status is not UNSET:
            field_dict["Status"] = status
        if name is not UNSET:
            field_dict["Name"] = name
        if key is not UNSET:
            field_dict["Key"] = key
        if id is not UNSET:
            field_dict["Id"] = id
        if error_message is not UNSET:
            field_dict["ErrorMessage"] = error_message
        if long_error_message is not UNSET:
            field_dict["LongErrorMessage"] = long_error_message

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _start_time_utc = d.pop("StartTimeUtc", UNSET)
        start_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_start_time_utc, Unset):
            start_time_utc = UNSET
        else:
            start_time_utc = isoparse(_start_time_utc)

        _end_time_utc = d.pop("EndTimeUtc", UNSET)
        end_time_utc: Union[Unset, datetime.datetime]
        if isinstance(_end_time_utc, Unset):
            end_time_utc = UNSET
        else:
            end_time_utc = isoparse(_end_time_utc)

        _status = d.pop("Status", UNSET)
        status: Union[Unset, TaskCompletionStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = TaskCompletionStatus(_status)

        name = d.pop("Name", UNSET)

        key = d.pop("Key", UNSET)

        id = d.pop("Id", UNSET)

        error_message = d.pop("ErrorMessage", UNSET)

        long_error_message = d.pop("LongErrorMessage", UNSET)

        task_result = cls(
            start_time_utc=start_time_utc,
            end_time_utc=end_time_utc,
            status=status,
            name=name,
            key=key,
            id=id,
            error_message=error_message,
            long_error_message=long_error_message,
        )

        return task_result



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.image_type import ImageType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.image_option import ImageOption
    from ..models.library_option_info_dto import LibraryOptionInfoDto


T = TypeVar("T", bound="LibraryTypeOptionsDto")


@_attrs_define
class LibraryTypeOptionsDto:
    """Library type options dto.

    Attributes:
        type (Union[Unset, None, str]): Gets or sets the type.
        metadata_fetchers (Union[Unset, List['LibraryOptionInfoDto']]): Gets or sets the metadata fetchers.
        image_fetchers (Union[Unset, List['LibraryOptionInfoDto']]): Gets or sets the image fetchers.
        supported_image_types (Union[Unset, List[ImageType]]): Gets or sets the supported image types.
        default_image_options (Union[Unset, List['ImageOption']]): Gets or sets the default image options.
    """

    type: Union[Unset, None, str] = UNSET
    metadata_fetchers: Union[Unset, List["LibraryOptionInfoDto"]] = UNSET
    image_fetchers: Union[Unset, List["LibraryOptionInfoDto"]] = UNSET
    supported_image_types: Union[Unset, List[ImageType]] = UNSET
    default_image_options: Union[Unset, List["ImageOption"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        metadata_fetchers: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.metadata_fetchers, Unset):
            metadata_fetchers = []
            for metadata_fetchers_item_data in self.metadata_fetchers:
                metadata_fetchers_item = metadata_fetchers_item_data.to_dict()

                metadata_fetchers.append(metadata_fetchers_item)

        image_fetchers: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.image_fetchers, Unset):
            image_fetchers = []
            for image_fetchers_item_data in self.image_fetchers:
                image_fetchers_item = image_fetchers_item_data.to_dict()

                image_fetchers.append(image_fetchers_item)

        supported_image_types: Union[Unset, List[str]] = UNSET
        if not isinstance(self.supported_image_types, Unset):
            supported_image_types = []
            for supported_image_types_item_data in self.supported_image_types:
                supported_image_types_item = supported_image_types_item_data.value

                supported_image_types.append(supported_image_types_item)

        default_image_options: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.default_image_options, Unset):
            default_image_options = []
            for default_image_options_item_data in self.default_image_options:
                default_image_options_item = default_image_options_item_data.to_dict()

                default_image_options.append(default_image_options_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["Type"] = type
        if metadata_fetchers is not UNSET:
            field_dict["MetadataFetchers"] = metadata_fetchers
        if image_fetchers is not UNSET:
            field_dict["ImageFetchers"] = image_fetchers
        if supported_image_types is not UNSET:
            field_dict["SupportedImageTypes"] = supported_image_types
        if default_image_options is not UNSET:
            field_dict["DefaultImageOptions"] = default_image_options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.image_option import ImageOption
        from ..models.library_option_info_dto import LibraryOptionInfoDto

        d = src_dict.copy()
        type = d.pop("Type", UNSET)

        metadata_fetchers = []
        _metadata_fetchers = d.pop("MetadataFetchers", UNSET)
        for metadata_fetchers_item_data in _metadata_fetchers or []:
            metadata_fetchers_item = LibraryOptionInfoDto.from_dict(metadata_fetchers_item_data)

            metadata_fetchers.append(metadata_fetchers_item)

        image_fetchers = []
        _image_fetchers = d.pop("ImageFetchers", UNSET)
        for image_fetchers_item_data in _image_fetchers or []:
            image_fetchers_item = LibraryOptionInfoDto.from_dict(image_fetchers_item_data)

            image_fetchers.append(image_fetchers_item)

        supported_image_types = []
        _supported_image_types = d.pop("SupportedImageTypes", UNSET)
        for supported_image_types_item_data in _supported_image_types or []:
            supported_image_types_item = ImageType(supported_image_types_item_data)

            supported_image_types.append(supported_image_types_item)

        default_image_options = []
        _default_image_options = d.pop("DefaultImageOptions", UNSET)
        for default_image_options_item_data in _default_image_options or []:
            default_image_options_item = ImageOption.from_dict(default_image_options_item_data)

            default_image_options.append(default_image_options_item)

        library_type_options_dto = cls(
            type=type,
            metadata_fetchers=metadata_fetchers,
            image_fetchers=image_fetchers,
            supported_image_types=supported_image_types,
            default_image_options=default_image_options,
        )

        return library_type_options_dto



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.book_info import BookInfo


T = TypeVar("T", bound="BookInfoRemoteSearchQuery")


@_attrs_define
class BookInfoRemoteSearchQuery:
    """
    Attributes:
        search_info (Union[Unset, None, BookInfo]):
        item_id (Union[Unset, str]):
        search_provider_name (Union[Unset, None, str]): Gets or sets the provider name to search within if set.
        include_disabled_providers (Union[Unset, bool]): Gets or sets a value indicating whether disabled providers
            should be included.
    """

    search_info: Union[Unset, None, "BookInfo"] = UNSET
    item_id: Union[Unset, str] = UNSET
    search_provider_name: Union[Unset, None, str] = UNSET
    include_disabled_providers: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        search_info: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.search_info, Unset):
            search_info = self.search_info.to_dict() if self.search_info else None

        item_id = self.item_id
        search_provider_name = self.search_provider_name
        include_disabled_providers = self.include_disabled_providers

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if search_info is not UNSET:
            field_dict["SearchInfo"] = search_info
        if item_id is not UNSET:
            field_dict["ItemId"] = item_id
        if search_provider_name is not UNSET:
            field_dict["SearchProviderName"] = search_provider_name
        if include_disabled_providers is not UNSET:
            field_dict["IncludeDisabledProviders"] = include_disabled_providers

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.book_info import BookInfo

        d = src_dict.copy()
        _search_info = d.pop("SearchInfo", UNSET)
        search_info: Union[Unset, None, BookInfo]
        if _search_info is None:
            search_info = None
        elif isinstance(_search_info, Unset):
            search_info = UNSET
        else:
            search_info = BookInfo.from_dict(_search_info)

        item_id = d.pop("ItemId", UNSET)

        search_provider_name = d.pop("SearchProviderName", UNSET)

        include_disabled_providers = d.pop("IncludeDisabledProviders", UNSET)

        book_info_remote_search_query = cls(
            search_info=search_info,
            item_id=item_id,
            search_provider_name=search_provider_name,
            include_disabled_providers=include_disabled_providers,
        )

        return book_info_remote_search_query



from enum import Enum


class MediaSourceType(str, Enum):
    DEFAULT = "Default"
    GROUPING = "Grouping"
    PLACEHOLDER = "Placeholder"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.image_type import ImageType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ImageInfo")


@_attrs_define
class ImageInfo:
    """Class ImageInfo.

    Attributes:
        image_type (Union[Unset, ImageType]): Enum ImageType.
        image_index (Union[Unset, None, int]): Gets or sets the index of the image.
        image_tag (Union[Unset, None, str]): Gets or sets the image tag.
        path (Union[Unset, None, str]): Gets or sets the path.
        blur_hash (Union[Unset, None, str]): Gets or sets the blurhash.
        height (Union[Unset, None, int]): Gets or sets the height.
        width (Union[Unset, None, int]): Gets or sets the width.
        size (Union[Unset, int]): Gets or sets the size.
    """

    image_type: Union[Unset, ImageType] = UNSET
    image_index: Union[Unset, None, int] = UNSET
    image_tag: Union[Unset, None, str] = UNSET
    path: Union[Unset, None, str] = UNSET
    blur_hash: Union[Unset, None, str] = UNSET
    height: Union[Unset, None, int] = UNSET
    width: Union[Unset, None, int] = UNSET
    size: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        image_type: Union[Unset, str] = UNSET
        if not isinstance(self.image_type, Unset):
            image_type = self.image_type.value

        image_index = self.image_index
        image_tag = self.image_tag
        path = self.path
        blur_hash = self.blur_hash
        height = self.height
        width = self.width
        size = self.size

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if image_type is not UNSET:
            field_dict["ImageType"] = image_type
        if image_index is not UNSET:
            field_dict["ImageIndex"] = image_index
        if image_tag is not UNSET:
            field_dict["ImageTag"] = image_tag
        if path is not UNSET:
            field_dict["Path"] = path
        if blur_hash is not UNSET:
            field_dict["BlurHash"] = blur_hash
        if height is not UNSET:
            field_dict["Height"] = height
        if width is not UNSET:
            field_dict["Width"] = width
        if size is not UNSET:
            field_dict["Size"] = size

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _image_type = d.pop("ImageType", UNSET)
        image_type: Union[Unset, ImageType]
        if isinstance(_image_type, Unset):
            image_type = UNSET
        else:
            image_type = ImageType(_image_type)

        image_index = d.pop("ImageIndex", UNSET)

        image_tag = d.pop("ImageTag", UNSET)

        path = d.pop("Path", UNSET)

        blur_hash = d.pop("BlurHash", UNSET)

        height = d.pop("Height", UNSET)

        width = d.pop("Width", UNSET)

        size = d.pop("Size", UNSET)

        image_info = cls(
            image_type=image_type,
            image_index=image_index,
            image_tag=image_tag,
            path=path,
            blur_hash=blur_hash,
            height=height,
            width=width,
            size=size,
        )

        return image_info



from enum import Enum


class GroupStateType(str, Enum):
    IDLE = "Idle"
    PAUSED = "Paused"
    PLAYING = "Playing"
    WAITING = "Waiting"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.profile_condition_type import ProfileConditionType
from ..models.profile_condition_value import ProfileConditionValue
from ..types import UNSET, Unset

T = TypeVar("T", bound="ProfileCondition")


@_attrs_define
class ProfileCondition:
    """
    Attributes:
        condition (Union[Unset, ProfileConditionType]):
        property_ (Union[Unset, ProfileConditionValue]):
        value (Union[Unset, None, str]):
        is_required (Union[Unset, bool]):
    """

    condition: Union[Unset, ProfileConditionType] = UNSET
    property_: Union[Unset, ProfileConditionValue] = UNSET
    value: Union[Unset, None, str] = UNSET
    is_required: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        condition: Union[Unset, str] = UNSET
        if not isinstance(self.condition, Unset):
            condition = self.condition.value

        property_: Union[Unset, str] = UNSET
        if not isinstance(self.property_, Unset):
            property_ = self.property_.value

        value = self.value
        is_required = self.is_required

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if condition is not UNSET:
            field_dict["Condition"] = condition
        if property_ is not UNSET:
            field_dict["Property"] = property_
        if value is not UNSET:
            field_dict["Value"] = value
        if is_required is not UNSET:
            field_dict["IsRequired"] = is_required

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _condition = d.pop("Condition", UNSET)
        condition: Union[Unset, ProfileConditionType]
        if isinstance(_condition, Unset):
            condition = UNSET
        else:
            condition = ProfileConditionType(_condition)

        _property_ = d.pop("Property", UNSET)
        property_: Union[Unset, ProfileConditionValue]
        if isinstance(_property_, Unset):
            property_ = UNSET
        else:
            property_ = ProfileConditionValue(_property_)

        value = d.pop("Value", UNSET)

        is_required = d.pop("IsRequired", UNSET)

        profile_condition = cls(
            condition=condition,
            property_=property_,
            value=value,
            is_required=is_required,
        )

        return profile_condition



from enum import Enum


class MetadataRefreshMode(str, Enum):
    DEFAULT = "Default"
    FULLREFRESH = "FullRefresh"
    NONE = "None"
    VALIDATIONONLY = "ValidationOnly"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.client_capabilities import ClientCapabilities


T = TypeVar("T", bound="DeviceInfo")


@_attrs_define
class DeviceInfo:
    """
    Attributes:
        name (Union[Unset, None, str]):
        access_token (Union[Unset, None, str]): Gets or sets the access token.
        id (Union[Unset, None, str]): Gets or sets the identifier.
        last_user_name (Union[Unset, None, str]): Gets or sets the last name of the user.
        app_name (Union[Unset, None, str]): Gets or sets the name of the application.
        app_version (Union[Unset, None, str]): Gets or sets the application version.
        last_user_id (Union[Unset, str]): Gets or sets the last user identifier.
        date_last_activity (Union[Unset, datetime.datetime]): Gets or sets the date last modified.
        capabilities (Union[Unset, None, ClientCapabilities]):
        icon_url (Union[Unset, None, str]):
    """

    name: Union[Unset, None, str] = UNSET
    access_token: Union[Unset, None, str] = UNSET
    id: Union[Unset, None, str] = UNSET
    last_user_name: Union[Unset, None, str] = UNSET
    app_name: Union[Unset, None, str] = UNSET
    app_version: Union[Unset, None, str] = UNSET
    last_user_id: Union[Unset, str] = UNSET
    date_last_activity: Union[Unset, datetime.datetime] = UNSET
    capabilities: Union[Unset, None, "ClientCapabilities"] = UNSET
    icon_url: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        access_token = self.access_token
        id = self.id
        last_user_name = self.last_user_name
        app_name = self.app_name
        app_version = self.app_version
        last_user_id = self.last_user_id
        date_last_activity: Union[Unset, str] = UNSET
        if not isinstance(self.date_last_activity, Unset):
            date_last_activity = self.date_last_activity.isoformat()

        capabilities: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.capabilities, Unset):
            capabilities = self.capabilities.to_dict() if self.capabilities else None

        icon_url = self.icon_url

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if access_token is not UNSET:
            field_dict["AccessToken"] = access_token
        if id is not UNSET:
            field_dict["Id"] = id
        if last_user_name is not UNSET:
            field_dict["LastUserName"] = last_user_name
        if app_name is not UNSET:
            field_dict["AppName"] = app_name
        if app_version is not UNSET:
            field_dict["AppVersion"] = app_version
        if last_user_id is not UNSET:
            field_dict["LastUserId"] = last_user_id
        if date_last_activity is not UNSET:
            field_dict["DateLastActivity"] = date_last_activity
        if capabilities is not UNSET:
            field_dict["Capabilities"] = capabilities
        if icon_url is not UNSET:
            field_dict["IconUrl"] = icon_url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.client_capabilities import ClientCapabilities

        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        access_token = d.pop("AccessToken", UNSET)

        id = d.pop("Id", UNSET)

        last_user_name = d.pop("LastUserName", UNSET)

        app_name = d.pop("AppName", UNSET)

        app_version = d.pop("AppVersion", UNSET)

        last_user_id = d.pop("LastUserId", UNSET)

        _date_last_activity = d.pop("DateLastActivity", UNSET)
        date_last_activity: Union[Unset, datetime.datetime]
        if isinstance(_date_last_activity, Unset):
            date_last_activity = UNSET
        else:
            date_last_activity = isoparse(_date_last_activity)

        _capabilities = d.pop("Capabilities", UNSET)
        capabilities: Union[Unset, None, ClientCapabilities]
        if _capabilities is None:
            capabilities = None
        elif isinstance(_capabilities, Unset):
            capabilities = UNSET
        else:
            capabilities = ClientCapabilities.from_dict(_capabilities)

        icon_url = d.pop("IconUrl", UNSET)

        device_info = cls(
            name=name,
            access_token=access_token,
            id=id,
            last_user_name=last_user_name,
            app_name=app_name,
            app_version=app_version,
            last_user_id=last_user_id,
            date_last_activity=date_last_activity,
            capabilities=capabilities,
            icon_url=icon_url,
        )

        return device_info



from enum import Enum


class Architecture(str, Enum):
    ARM = "Arm"
    ARM64 = "Arm64"
    S390X = "S390x"
    WASM = "Wasm"
    X64 = "X64"
    X86 = "X86"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.send_to_user_type import SendToUserType
from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationOption")


@_attrs_define
class NotificationOption:
    """
    Attributes:
        type (Union[Unset, None, str]):
        disabled_monitor_users (Union[Unset, List[str]]): Gets or sets user Ids to not monitor (it's opt out).
        send_to_users (Union[Unset, List[str]]): Gets or sets user Ids to send to (if SendToUserMode == Custom).
        enabled (Union[Unset, bool]): Gets or sets a value indicating whether this
            MediaBrowser.Model.Notifications.NotificationOption is enabled.
        disabled_services (Union[Unset, List[str]]): Gets or sets the disabled services.
        send_to_user_mode (Union[Unset, SendToUserType]):
    """

    type: Union[Unset, None, str] = UNSET
    disabled_monitor_users: Union[Unset, List[str]] = UNSET
    send_to_users: Union[Unset, List[str]] = UNSET
    enabled: Union[Unset, bool] = UNSET
    disabled_services: Union[Unset, List[str]] = UNSET
    send_to_user_mode: Union[Unset, SendToUserType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        disabled_monitor_users: Union[Unset, List[str]] = UNSET
        if not isinstance(self.disabled_monitor_users, Unset):
            disabled_monitor_users = self.disabled_monitor_users

        send_to_users: Union[Unset, List[str]] = UNSET
        if not isinstance(self.send_to_users, Unset):
            send_to_users = self.send_to_users

        enabled = self.enabled
        disabled_services: Union[Unset, List[str]] = UNSET
        if not isinstance(self.disabled_services, Unset):
            disabled_services = self.disabled_services

        send_to_user_mode: Union[Unset, str] = UNSET
        if not isinstance(self.send_to_user_mode, Unset):
            send_to_user_mode = self.send_to_user_mode.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["Type"] = type
        if disabled_monitor_users is not UNSET:
            field_dict["DisabledMonitorUsers"] = disabled_monitor_users
        if send_to_users is not UNSET:
            field_dict["SendToUsers"] = send_to_users
        if enabled is not UNSET:
            field_dict["Enabled"] = enabled
        if disabled_services is not UNSET:
            field_dict["DisabledServices"] = disabled_services
        if send_to_user_mode is not UNSET:
            field_dict["SendToUserMode"] = send_to_user_mode

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = d.pop("Type", UNSET)

        disabled_monitor_users = cast(List[str], d.pop("DisabledMonitorUsers", UNSET))

        send_to_users = cast(List[str], d.pop("SendToUsers", UNSET))

        enabled = d.pop("Enabled", UNSET)

        disabled_services = cast(List[str], d.pop("DisabledServices", UNSET))

        _send_to_user_mode = d.pop("SendToUserMode", UNSET)
        send_to_user_mode: Union[Unset, SendToUserType]
        if isinstance(_send_to_user_mode, Unset):
            send_to_user_mode = UNSET
        else:
            send_to_user_mode = SendToUserType(_send_to_user_mode)

        notification_option = cls(
            type=type,
            disabled_monitor_users=disabled_monitor_users,
            send_to_users=send_to_users,
            enabled=enabled,
            disabled_services=disabled_services,
            send_to_user_mode=send_to_user_mode,
        )

        return notification_option



from enum import Enum


class KeepUntil(str, Enum):
    UNTILDATE = "UntilDate"
    UNTILDELETED = "UntilDeleted"
    UNTILSPACENEEDED = "UntilSpaceNeeded"
    UNTILWATCHED = "UntilWatched"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class ProfileConditionValue(str, Enum):
    AUDIOBITDEPTH = "AudioBitDepth"
    AUDIOBITRATE = "AudioBitrate"
    AUDIOCHANNELS = "AudioChannels"
    AUDIOPROFILE = "AudioProfile"
    AUDIOSAMPLERATE = "AudioSampleRate"
    HAS64BITOFFSETS = "Has64BitOffsets"
    HEIGHT = "Height"
    ISANAMORPHIC = "IsAnamorphic"
    ISAVC = "IsAvc"
    ISINTERLACED = "IsInterlaced"
    ISSECONDARYAUDIO = "IsSecondaryAudio"
    NUMAUDIOSTREAMS = "NumAudioStreams"
    NUMVIDEOSTREAMS = "NumVideoStreams"
    PACKETLENGTH = "PacketLength"
    REFFRAMES = "RefFrames"
    VIDEOBITDEPTH = "VideoBitDepth"
    VIDEOBITRATE = "VideoBitrate"
    VIDEOCODECTAG = "VideoCodecTag"
    VIDEOFRAMERATE = "VideoFramerate"
    VIDEOLEVEL = "VideoLevel"
    VIDEOPROFILE = "VideoProfile"
    VIDEORANGETYPE = "VideoRangeType"
    VIDEOTIMESTAMP = "VideoTimestamp"
    WIDTH = "Width"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ConfigurationPageInfo")


@_attrs_define
class ConfigurationPageInfo:
    """The configuration page info.

    Attributes:
        name (Union[Unset, str]): Gets or sets the name.
        enable_in_main_menu (Union[Unset, bool]): Gets or sets a value indicating whether the configurations page is
            enabled in the main menu.
        menu_section (Union[Unset, None, str]): Gets or sets the menu section.
        menu_icon (Union[Unset, None, str]): Gets or sets the menu icon.
        display_name (Union[Unset, None, str]): Gets or sets the display name.
        plugin_id (Union[Unset, None, str]): Gets or sets the plugin id.
    """

    name: Union[Unset, str] = UNSET
    enable_in_main_menu: Union[Unset, bool] = UNSET
    menu_section: Union[Unset, None, str] = UNSET
    menu_icon: Union[Unset, None, str] = UNSET
    display_name: Union[Unset, None, str] = UNSET
    plugin_id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        enable_in_main_menu = self.enable_in_main_menu
        menu_section = self.menu_section
        menu_icon = self.menu_icon
        display_name = self.display_name
        plugin_id = self.plugin_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if enable_in_main_menu is not UNSET:
            field_dict["EnableInMainMenu"] = enable_in_main_menu
        if menu_section is not UNSET:
            field_dict["MenuSection"] = menu_section
        if menu_icon is not UNSET:
            field_dict["MenuIcon"] = menu_icon
        if display_name is not UNSET:
            field_dict["DisplayName"] = display_name
        if plugin_id is not UNSET:
            field_dict["PluginId"] = plugin_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        enable_in_main_menu = d.pop("EnableInMainMenu", UNSET)

        menu_section = d.pop("MenuSection", UNSET)

        menu_icon = d.pop("MenuIcon", UNSET)

        display_name = d.pop("DisplayName", UNSET)

        plugin_id = d.pop("PluginId", UNSET)

        configuration_page_info = cls(
            name=name,
            enable_in_main_menu=enable_in_main_menu,
            menu_section=menu_section,
            menu_icon=menu_icon,
            display_name=display_name,
            plugin_id=plugin_id,
        )

        return configuration_page_info



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.base_item_dto import BaseItemDto
    from ..models.queue_item import QueueItem


T = TypeVar("T", bound="PlaybackStopInfo")


@_attrs_define
class PlaybackStopInfo:
    """Class PlaybackStopInfo.

    Attributes:
        item (Union[Unset, None, BaseItemDto]): This is strictly used as a data transfer object from the api layer.
            This holds information about a BaseItem in a format that is convenient for the client.
        item_id (Union[Unset, str]): Gets or sets the item identifier.
        session_id (Union[Unset, None, str]): Gets or sets the session id.
        media_source_id (Union[Unset, None, str]): Gets or sets the media version identifier.
        position_ticks (Union[Unset, None, int]): Gets or sets the position ticks.
        live_stream_id (Union[Unset, None, str]): Gets or sets the live stream identifier.
        play_session_id (Union[Unset, None, str]): Gets or sets the play session identifier.
        failed (Union[Unset, bool]): Gets or sets a value indicating whether this
            MediaBrowser.Model.Session.PlaybackStopInfo is failed.
        next_media_type (Union[Unset, None, str]):
        playlist_item_id (Union[Unset, None, str]):
        now_playing_queue (Union[Unset, None, List['QueueItem']]):
    """

    item: Union[Unset, None, "BaseItemDto"] = UNSET
    item_id: Union[Unset, str] = UNSET
    session_id: Union[Unset, None, str] = UNSET
    media_source_id: Union[Unset, None, str] = UNSET
    position_ticks: Union[Unset, None, int] = UNSET
    live_stream_id: Union[Unset, None, str] = UNSET
    play_session_id: Union[Unset, None, str] = UNSET
    failed: Union[Unset, bool] = UNSET
    next_media_type: Union[Unset, None, str] = UNSET
    playlist_item_id: Union[Unset, None, str] = UNSET
    now_playing_queue: Union[Unset, None, List["QueueItem"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        item: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.item, Unset):
            item = self.item.to_dict() if self.item else None

        item_id = self.item_id
        session_id = self.session_id
        media_source_id = self.media_source_id
        position_ticks = self.position_ticks
        live_stream_id = self.live_stream_id
        play_session_id = self.play_session_id
        failed = self.failed
        next_media_type = self.next_media_type
        playlist_item_id = self.playlist_item_id
        now_playing_queue: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.now_playing_queue, Unset):
            if self.now_playing_queue is None:
                now_playing_queue = None
            else:
                now_playing_queue = []
                for now_playing_queue_item_data in self.now_playing_queue:
                    now_playing_queue_item = now_playing_queue_item_data.to_dict()

                    now_playing_queue.append(now_playing_queue_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if item is not UNSET:
            field_dict["Item"] = item
        if item_id is not UNSET:
            field_dict["ItemId"] = item_id
        if session_id is not UNSET:
            field_dict["SessionId"] = session_id
        if media_source_id is not UNSET:
            field_dict["MediaSourceId"] = media_source_id
        if position_ticks is not UNSET:
            field_dict["PositionTicks"] = position_ticks
        if live_stream_id is not UNSET:
            field_dict["LiveStreamId"] = live_stream_id
        if play_session_id is not UNSET:
            field_dict["PlaySessionId"] = play_session_id
        if failed is not UNSET:
            field_dict["Failed"] = failed
        if next_media_type is not UNSET:
            field_dict["NextMediaType"] = next_media_type
        if playlist_item_id is not UNSET:
            field_dict["PlaylistItemId"] = playlist_item_id
        if now_playing_queue is not UNSET:
            field_dict["NowPlayingQueue"] = now_playing_queue

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.base_item_dto import BaseItemDto
        from ..models.queue_item import QueueItem

        d = src_dict.copy()
        _item = d.pop("Item", UNSET)
        item: Union[Unset, None, BaseItemDto]
        if _item is None:
            item = None
        elif isinstance(_item, Unset):
            item = UNSET
        else:
            item = BaseItemDto.from_dict(_item)

        item_id = d.pop("ItemId", UNSET)

        session_id = d.pop("SessionId", UNSET)

        media_source_id = d.pop("MediaSourceId", UNSET)

        position_ticks = d.pop("PositionTicks", UNSET)

        live_stream_id = d.pop("LiveStreamId", UNSET)

        play_session_id = d.pop("PlaySessionId", UNSET)

        failed = d.pop("Failed", UNSET)

        next_media_type = d.pop("NextMediaType", UNSET)

        playlist_item_id = d.pop("PlaylistItemId", UNSET)

        now_playing_queue = []
        _now_playing_queue = d.pop("NowPlayingQueue", UNSET)
        for now_playing_queue_item_data in _now_playing_queue or []:
            now_playing_queue_item = QueueItem.from_dict(now_playing_queue_item_data)

            now_playing_queue.append(now_playing_queue_item)

        playback_stop_info = cls(
            item=item,
            item_id=item_id,
            session_id=session_id,
            media_source_id=media_source_id,
            position_ticks=position_ticks,
            live_stream_id=live_stream_id,
            play_session_id=play_session_id,
            failed=failed,
            next_media_type=next_media_type,
            playlist_item_id=playlist_item_id,
            now_playing_queue=now_playing_queue,
        )

        return playback_stop_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.dlna_profile_type import DlnaProfileType
from ..types import UNSET, Unset

T = TypeVar("T", bound="DirectPlayProfile")


@_attrs_define
class DirectPlayProfile:
    """
    Attributes:
        container (Union[Unset, None, str]):
        audio_codec (Union[Unset, None, str]):
        video_codec (Union[Unset, None, str]):
        type (Union[Unset, DlnaProfileType]):
    """

    container: Union[Unset, None, str] = UNSET
    audio_codec: Union[Unset, None, str] = UNSET
    video_codec: Union[Unset, None, str] = UNSET
    type: Union[Unset, DlnaProfileType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        container = self.container
        audio_codec = self.audio_codec
        video_codec = self.video_codec
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if container is not UNSET:
            field_dict["Container"] = container
        if audio_codec is not UNSET:
            field_dict["AudioCodec"] = audio_codec
        if video_codec is not UNSET:
            field_dict["VideoCodec"] = video_codec
        if type is not UNSET:
            field_dict["Type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        container = d.pop("Container", UNSET)

        audio_codec = d.pop("AudioCodec", UNSET)

        video_codec = d.pop("VideoCodec", UNSET)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, DlnaProfileType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = DlnaProfileType(_type)

        direct_play_profile = cls(
            container=container,
            audio_codec=audio_codec,
            video_codec=video_codec,
            type=type,
        )

        return direct_play_profile



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="DlnaOptions")


@_attrs_define
class DlnaOptions:
    """The DlnaOptions class contains the user definable parameters for the dlna subsystems.

    Attributes:
        enable_play_to (Union[Unset, bool]): Gets or sets a value indicating whether gets or sets a value to indicate
            the status of the dlna playTo subsystem.
        enable_server (Union[Unset, bool]): Gets or sets a value indicating whether gets or sets a value to indicate the
            status of the dlna server subsystem.
        enable_debug_log (Union[Unset, bool]): Gets or sets a value indicating whether detailed dlna server logs are
            sent to the console/log.
            If the setting "Emby.Dlna": "Debug" msut be set in logging.default.json for this property to work.
        enable_play_to_tracing (Union[Unset, bool]): Gets or sets a value indicating whether whether detailed playTo
            debug logs are sent to the console/log.
            If the setting "Emby.Dlna.PlayTo": "Debug" msut be set in logging.default.json for this property to work.
        client_discovery_interval_seconds (Union[Unset, int]): Gets or sets the ssdp client discovery interval time (in
            seconds).
            This is the time after which the server will send a ssdp search request.
        alive_message_interval_seconds (Union[Unset, int]): Gets or sets the frequency at which ssdp alive notifications
            are transmitted.
        blast_alive_message_interval_seconds (Union[Unset, int]): Gets or sets the frequency at which ssdp alive
            notifications are transmitted. MIGRATING - TO BE REMOVED ONCE WEB HAS BEEN ALTERED.
        default_user_id (Union[Unset, None, str]): Gets or sets the default user account that the dlna server uses.
        auto_create_play_to_profiles (Union[Unset, bool]): Gets or sets a value indicating whether playTo device
            profiles should be created.
        blast_alive_messages (Union[Unset, bool]): Gets or sets a value indicating whether to blast alive messages.
        send_only_matched_host (Union[Unset, bool]): gets or sets a value indicating whether to send only matched host.
    """

    enable_play_to: Union[Unset, bool] = UNSET
    enable_server: Union[Unset, bool] = UNSET
    enable_debug_log: Union[Unset, bool] = UNSET
    enable_play_to_tracing: Union[Unset, bool] = UNSET
    client_discovery_interval_seconds: Union[Unset, int] = UNSET
    alive_message_interval_seconds: Union[Unset, int] = UNSET
    blast_alive_message_interval_seconds: Union[Unset, int] = UNSET
    default_user_id: Union[Unset, None, str] = UNSET
    auto_create_play_to_profiles: Union[Unset, bool] = UNSET
    blast_alive_messages: Union[Unset, bool] = UNSET
    send_only_matched_host: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        enable_play_to = self.enable_play_to
        enable_server = self.enable_server
        enable_debug_log = self.enable_debug_log
        enable_play_to_tracing = self.enable_play_to_tracing
        client_discovery_interval_seconds = self.client_discovery_interval_seconds
        alive_message_interval_seconds = self.alive_message_interval_seconds
        blast_alive_message_interval_seconds = self.blast_alive_message_interval_seconds
        default_user_id = self.default_user_id
        auto_create_play_to_profiles = self.auto_create_play_to_profiles
        blast_alive_messages = self.blast_alive_messages
        send_only_matched_host = self.send_only_matched_host

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if enable_play_to is not UNSET:
            field_dict["EnablePlayTo"] = enable_play_to
        if enable_server is not UNSET:
            field_dict["EnableServer"] = enable_server
        if enable_debug_log is not UNSET:
            field_dict["EnableDebugLog"] = enable_debug_log
        if enable_play_to_tracing is not UNSET:
            field_dict["EnablePlayToTracing"] = enable_play_to_tracing
        if client_discovery_interval_seconds is not UNSET:
            field_dict["ClientDiscoveryIntervalSeconds"] = client_discovery_interval_seconds
        if alive_message_interval_seconds is not UNSET:
            field_dict["AliveMessageIntervalSeconds"] = alive_message_interval_seconds
        if blast_alive_message_interval_seconds is not UNSET:
            field_dict["BlastAliveMessageIntervalSeconds"] = blast_alive_message_interval_seconds
        if default_user_id is not UNSET:
            field_dict["DefaultUserId"] = default_user_id
        if auto_create_play_to_profiles is not UNSET:
            field_dict["AutoCreatePlayToProfiles"] = auto_create_play_to_profiles
        if blast_alive_messages is not UNSET:
            field_dict["BlastAliveMessages"] = blast_alive_messages
        if send_only_matched_host is not UNSET:
            field_dict["SendOnlyMatchedHost"] = send_only_matched_host

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        enable_play_to = d.pop("EnablePlayTo", UNSET)

        enable_server = d.pop("EnableServer", UNSET)

        enable_debug_log = d.pop("EnableDebugLog", UNSET)

        enable_play_to_tracing = d.pop("EnablePlayToTracing", UNSET)

        client_discovery_interval_seconds = d.pop("ClientDiscoveryIntervalSeconds", UNSET)

        alive_message_interval_seconds = d.pop("AliveMessageIntervalSeconds", UNSET)

        blast_alive_message_interval_seconds = d.pop("BlastAliveMessageIntervalSeconds", UNSET)

        default_user_id = d.pop("DefaultUserId", UNSET)

        auto_create_play_to_profiles = d.pop("AutoCreatePlayToProfiles", UNSET)

        blast_alive_messages = d.pop("BlastAliveMessages", UNSET)

        send_only_matched_host = d.pop("SendOnlyMatchedHost", UNSET)

        dlna_options = cls(
            enable_play_to=enable_play_to,
            enable_server=enable_server,
            enable_debug_log=enable_debug_log,
            enable_play_to_tracing=enable_play_to_tracing,
            client_discovery_interval_seconds=client_discovery_interval_seconds,
            alive_message_interval_seconds=alive_message_interval_seconds,
            blast_alive_message_interval_seconds=blast_alive_message_interval_seconds,
            default_user_id=default_user_id,
            auto_create_play_to_profiles=auto_create_play_to_profiles,
            blast_alive_messages=blast_alive_messages,
            send_only_matched_host=send_only_matched_host,
        )

        return dlna_options



from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.live_stream_response import LiveStreamResponse
from ...models.open_live_stream_dto import OpenLiveStreamDto
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    json_body: OpenLiveStreamDto,
    open_token: Union[Unset, None, str] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    max_streaming_bitrate: Union[Unset, None, int] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    item_id: Union[Unset, None, str] = UNSET,
    enable_direct_play: Union[Unset, None, bool] = UNSET,
    enable_direct_stream: Union[Unset, None, bool] = UNSET,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["openToken"] = open_token

    params["userId"] = user_id

    params["playSessionId"] = play_session_id

    params["maxStreamingBitrate"] = max_streaming_bitrate

    params["startTimeTicks"] = start_time_ticks

    params["audioStreamIndex"] = audio_stream_index

    params["subtitleStreamIndex"] = subtitle_stream_index

    params["maxAudioChannels"] = max_audio_channels

    params["itemId"] = item_id

    params["enableDirectPlay"] = enable_direct_play

    params["enableDirectStream"] = enable_direct_stream

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/LiveStreams/Open",
        "json": json_json_body,
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, LiveStreamResponse]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = LiveStreamResponse.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, LiveStreamResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: OpenLiveStreamDto,
    open_token: Union[Unset, None, str] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    max_streaming_bitrate: Union[Unset, None, int] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    item_id: Union[Unset, None, str] = UNSET,
    enable_direct_play: Union[Unset, None, bool] = UNSET,
    enable_direct_stream: Union[Unset, None, bool] = UNSET,
) -> Response[Union[Any, LiveStreamResponse]]:
    """Opens a media source.

    Args:
        open_token (Union[Unset, None, str]):
        user_id (Union[Unset, None, str]):
        play_session_id (Union[Unset, None, str]):
        max_streaming_bitrate (Union[Unset, None, int]):
        start_time_ticks (Union[Unset, None, int]):
        audio_stream_index (Union[Unset, None, int]):
        subtitle_stream_index (Union[Unset, None, int]):
        max_audio_channels (Union[Unset, None, int]):
        item_id (Union[Unset, None, str]):
        enable_direct_play (Union[Unset, None, bool]):
        enable_direct_stream (Union[Unset, None, bool]):
        json_body (OpenLiveStreamDto): Open live stream dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, LiveStreamResponse]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        open_token=open_token,
        user_id=user_id,
        play_session_id=play_session_id,
        max_streaming_bitrate=max_streaming_bitrate,
        start_time_ticks=start_time_ticks,
        audio_stream_index=audio_stream_index,
        subtitle_stream_index=subtitle_stream_index,
        max_audio_channels=max_audio_channels,
        item_id=item_id,
        enable_direct_play=enable_direct_play,
        enable_direct_stream=enable_direct_stream,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: OpenLiveStreamDto,
    open_token: Union[Unset, None, str] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    max_streaming_bitrate: Union[Unset, None, int] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    item_id: Union[Unset, None, str] = UNSET,
    enable_direct_play: Union[Unset, None, bool] = UNSET,
    enable_direct_stream: Union[Unset, None, bool] = UNSET,
) -> Optional[Union[Any, LiveStreamResponse]]:
    """Opens a media source.

    Args:
        open_token (Union[Unset, None, str]):
        user_id (Union[Unset, None, str]):
        play_session_id (Union[Unset, None, str]):
        max_streaming_bitrate (Union[Unset, None, int]):
        start_time_ticks (Union[Unset, None, int]):
        audio_stream_index (Union[Unset, None, int]):
        subtitle_stream_index (Union[Unset, None, int]):
        max_audio_channels (Union[Unset, None, int]):
        item_id (Union[Unset, None, str]):
        enable_direct_play (Union[Unset, None, bool]):
        enable_direct_stream (Union[Unset, None, bool]):
        json_body (OpenLiveStreamDto): Open live stream dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, LiveStreamResponse]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        open_token=open_token,
        user_id=user_id,
        play_session_id=play_session_id,
        max_streaming_bitrate=max_streaming_bitrate,
        start_time_ticks=start_time_ticks,
        audio_stream_index=audio_stream_index,
        subtitle_stream_index=subtitle_stream_index,
        max_audio_channels=max_audio_channels,
        item_id=item_id,
        enable_direct_play=enable_direct_play,
        enable_direct_stream=enable_direct_stream,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: OpenLiveStreamDto,
    open_token: Union[Unset, None, str] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    max_streaming_bitrate: Union[Unset, None, int] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    item_id: Union[Unset, None, str] = UNSET,
    enable_direct_play: Union[Unset, None, bool] = UNSET,
    enable_direct_stream: Union[Unset, None, bool] = UNSET,
) -> Response[Union[Any, LiveStreamResponse]]:
    """Opens a media source.

    Args:
        open_token (Union[Unset, None, str]):
        user_id (Union[Unset, None, str]):
        play_session_id (Union[Unset, None, str]):
        max_streaming_bitrate (Union[Unset, None, int]):
        start_time_ticks (Union[Unset, None, int]):
        audio_stream_index (Union[Unset, None, int]):
        subtitle_stream_index (Union[Unset, None, int]):
        max_audio_channels (Union[Unset, None, int]):
        item_id (Union[Unset, None, str]):
        enable_direct_play (Union[Unset, None, bool]):
        enable_direct_stream (Union[Unset, None, bool]):
        json_body (OpenLiveStreamDto): Open live stream dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, LiveStreamResponse]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
        open_token=open_token,
        user_id=user_id,
        play_session_id=play_session_id,
        max_streaming_bitrate=max_streaming_bitrate,
        start_time_ticks=start_time_ticks,
        audio_stream_index=audio_stream_index,
        subtitle_stream_index=subtitle_stream_index,
        max_audio_channels=max_audio_channels,
        item_id=item_id,
        enable_direct_play=enable_direct_play,
        enable_direct_stream=enable_direct_stream,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: OpenLiveStreamDto,
    open_token: Union[Unset, None, str] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    play_session_id: Union[Unset, None, str] = UNSET,
    max_streaming_bitrate: Union[Unset, None, int] = UNSET,
    start_time_ticks: Union[Unset, None, int] = UNSET,
    audio_stream_index: Union[Unset, None, int] = UNSET,
    subtitle_stream_index: Union[Unset, None, int] = UNSET,
    max_audio_channels: Union[Unset, None, int] = UNSET,
    item_id: Union[Unset, None, str] = UNSET,
    enable_direct_play: Union[Unset, None, bool] = UNSET,
    enable_direct_stream: Union[Unset, None, bool] = UNSET,
) -> Optional[Union[Any, LiveStreamResponse]]:
    """Opens a media source.

    Args:
        open_token (Union[Unset, None, str]):
        user_id (Union[Unset, None, str]):
        play_session_id (Union[Unset, None, str]):
        max_streaming_bitrate (Union[Unset, None, int]):
        start_time_ticks (Union[Unset, None, int]):
        audio_stream_index (Union[Unset, None, int]):
        subtitle_stream_index (Union[Unset, None, int]):
        max_audio_channels (Union[Unset, None, int]):
        item_id (Union[Unset, None, str]):
        enable_direct_play (Union[Unset, None, bool]):
        enable_direct_stream (Union[Unset, None, bool]):
        json_body (OpenLiveStreamDto): Open live stream dto.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, LiveStreamResponse]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            open_token=open_token,
            user_id=user_id,
            play_session_id=play_session_id,
            max_streaming_bitrate=max_streaming_bitrate,
            start_time_ticks=start_time_ticks,
            audio_stream_index=audio_stream_index,
            subtitle_stream_index=subtitle_stream_index,
            max_audio_channels=max_audio_channels,
            item_id=item_id,
            enable_direct_play=enable_direct_play,
            enable_direct_stream=enable_direct_stream,
        )
    ).parsed
